@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our %ANSI_TO_ASCII_TRANSLITERATION = (qw(
          !
@@ -764,12 +764,13 @@ sub to_latin1($) {
     s/Angstrm/ngstrm/g;
     s/Egalite/galit/g;
     s/(?<=[Ll]and)bue/busse/g;
-    s/\b(?<![])a(?=\W+(?:condition|deux mains|fonds perdu|gogo|jour|la))//g;
+    s/\b(?<![])a(?=\W+(?:condition|deux mains|fonds perdu|gogo|jour|la)\b)//g;
     s/(?<![\w])a discretion/ discrtion/g;
     s/(?<=[Bb]ai)(?=e)/ss/g;
     s/(?<=[Hh]au)(?=e)/ss/g;
     s/\bue\././g;
     s/berflo/berfloss/g;
+    s/\blo(?!\w)/loss/g;
     s/chm/Aechm/g;  # e.g. Aechmea
     s/(?<=[Aa]n)(?=ro)/ae/g;
     s/prter/praeter/g;
